# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2024-04-09

### Added

- First release of pm-remez.

[unreleased]: https://github.com/maia-sdr/pm-remez/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/maia-sdr/pm-remez/releases/tag/v0.1.0
